%ifarch %{ix86} x86_64
%define with_tboot 1
%else
%define with_tboot 0
%endif
%define enable_tnc 1

Name:    openpts
Summary: TCG Platform Trust Service (PTS)
Version: 0.2.6
Release: 13%{?dist}
License: CPL
Group:   Applications/System
Url:     http://sourceforge.jp/projects/openpts/
Source0: http://sourceforge.jp/projects/openpts/downloads/54410/openpts-%{version}.tar.gz
Source1: ptsc.service

# seems like coding errors
Patch1: bugs.patch
Patch2: openpts-zlib.patch
Patch3: openpts-zlib-fixes.patch
Patch4: openpts-ptsc-issues.patch

BuildRequires:    autoconf automake libtool trousers-devel openssl-devel 
BuildRequires:    libxml2-devel libuuid-devel gettext-devel systemd
Requires:         trousers >= 0.3.6, openssl >= 1.0.0, libxml2, libuuid
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
%if %{enable_tnc}
BuildRequires:    libtnc-devel
Requires:         libtnc
%endif
%if %{with_tboot}
Requires: tboot
%endif

%description
OpenPTS is an open-source package of Platform Trust Service (PTS)
defined by Trusted Computing Group (TCG). Trusted Computing is a set of
specifications set forth by the Trusted Computing Group (TCG).

%prep
%setup -q

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
sh bootstrap.sh
%configure --disable-static --prefix=/usr --libdir=%{_libdir} --with-tss --with-aru \
%if %{with_tboot}
  --with-tboot \
%endif
%if %{enable_tnc}
  --enable-tnc
%endif
#fails due to -lopenpts in src/Makefile.am
#make %{?_smp_mflags}
make

%install
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}
cp -p %{SOURCE1} %{buildroot}%{_unitdir}
cp -p dist/ptsc.conf.in %{buildroot}%{_sysconfdir}/ptsc.conf
cp -p dist/ptsv.conf.in %{buildroot}%{_sysconfdir}/ptsv.conf
mkdir -p %{buildroot}%{_datadir}/openpts/models
cp -p models/*.uml %{buildroot}%{_datadir}/openpts/models/
mkdir -p %{buildroot}%{_var}/lib/openpts

mkdir -p %{buildroot}%{_datadir}/openpts/tpm_emulator
cp dist/tpm_emulator/README.rhel %{buildroot}%{_datadir}/openpts/tpm_emulator/README
cp dist/tpm_emulator/binary_bios_measurements %{buildroot}%{_datadir}/openpts/tpm_emulator/
cp dist/tpm_emulator/tcsd %{buildroot}%{_datadir}/openpts/tpm_emulator/

%if %{with_tboot}
mkdir -p %{buildroot}%{_datadir}/openpts/tboot
cp dist/tboot/README.fedora15 %{buildroot}%{_datadir}/openpts/tboot/README
cp dist/tboot/ptsc.conf.fedora15 %{buildroot}%{_datadir}/openpts/tboot/ptsc.conf
cp dist/tboot/tcsd.conf.fedora15 %{buildroot}%{_datadir}/openpts/tboot/tcsd.conf
cp dist/tboot/tcsd.fedora15 %{buildroot}%{_datadir}/openpts/tboot/tcsd
%endif

make install DESTDIR=%{buildroot} INSTALL='install -p'

%find_lang %{name}

# Remove libtool archives
find %{buildroot} -type f -name "*.la" -delete

%pre
getent group ptsc >/dev/null || groupadd -r ptsc

%post
/usr/sbin/ldconfig
%systemd_post ptsc.service

%postun
/usr/sbin/ldconfig
%systemd_postun_with_restart ptsc.service 

%preun
%systemd_preun ptsc.service

%files -f %{name}.lang
%doc LICENSE README ChangeLog doc/*.eps
%attr(755, root, root) %{_sbindir}/ptsc
%attr(755, root, root) %{_bindir}/openpts
%attr(755, root, root) %{_bindir}/uml2dot
%attr(755, root, root) %{_bindir}/tpm_createkey
%attr(755, root, root) %{_bindir}/tpm_readpcr
%attr(755, root, root) %{_bindir}/tpm_extendpcr
%attr(755, root, root) %{_bindir}/iml2text
%attr(755, root, root) %{_bindir}/ir2text
%attr(755, root, root) %{_bindir}/rm2dot
%if %{with_tboot}
%attr(755, root, root) %{_bindir}/tboot2iml
%{_datadir}/openpts/tboot/*
%attr(755,root,root) %dir %{_datadir}/openpts/tboot
%endif
%{_libdir}/libopenpts.so
%{_libdir}/libopenpts-0.0.2.6.so
%if %{enable_tnc}
%{_libdir}/libopenpts_imc*so
%{_libdir}/libopenpts_imv*so
%endif
%{_datadir}/openpts/models/*uml
%{_datadir}/openpts/tpm_emulator/*
%attr(755,root,root) %dir %{_datadir}/openpts
%attr(755,root,root) %dir %{_datadir}/openpts/models
%attr(755,root,root) %dir %{_datadir}/openpts/tpm_emulator
%attr(755,root,root) %dir %{_var}/lib/openpts
%attr(0640, root, ptsc) %config(noreplace) %{_sysconfdir}/ptsc.conf
%attr(0640, root, ptsc) %config(noreplace) %{_sysconfdir}/ptsv.conf
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_unitdir}/ptsc.service

%changelog
* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.6-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 24 2014 Peter Robinson <pbrobinson@fedoraproject.org> 0.2.6-10
- Fix use of architecture declaration
- Convert to systemd unit files
- Modernise spec

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Oct 3 2013 Avesh Agarwal <avagarwa@redhat.com> - 0.2.6-8
- Removed building openpts on arm arch as tboot is not built on 
  arm arch, so koji keeps sending emails about broken 
  dependencies errors for tboot on arm platform.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Aug 21 2012 Avesh Agarwal <avagarwa@redhat.com> - 0.2.6-5
- Fixed ptsc implementation issues around setegid.

* Mon Jul 23 2012 Avesh Agarwal <avagarwa@redhat.com> - 0.2.6-4
- Fixed passing of incorrect file descriptor to zlip APIs

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jan 9 2012 Avesh Agarwal <avagarwa@redhat.com> - 0.2.6-2
- Fixed explicit linking of zlib

* Mon Jan 9 2012 Avesh Agarwal <avagarwa@redhat.com> - 0.2.6-1
- New upstream release 0.2.6
- Removed aide support
- Added ARU support
- Updated spec files
- Modified patches as per new release

* Mon Aug 15 2011 Kalev Lember <kalevlember@gmail.com> - 0.2.5-2
- Rebuilt for rpm bug #728707

* Wed Jul 20 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.2.5-1
- New upstream release 0.2.5
- Fixed spec file and updated local patches

* Tue Jun 7 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.2.4-1
- Initial build on F16
- Latest upstream release 0.2.4
- Enabled support for tnc and tboot
- Upstream changes: ptscd to ptsc, and ptscd.conf to ptsc.conf
- Fixed cleaning of tpm_emaulator and tboot dirs upon uninstall
- Many changes to spec file due to enabling of tnc and tboot
- Fixed local patches

* Fri Apr 15 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.2.3-3
- committed files in fedora and did initial build

* Wed Apr 13 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.2.3-2
- Fixed spec file issues found during package review 
  https://bugzilla.redhat.com/show_bug.cgi?id=691818

* Mon Mar 28 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.2.3-1
- Initial fedora packaging
- Added patch for fixing compile errors
- fixed init script inconsistency issue related 
  to its /var/lock/subsys file
